<?php

namespace DC\AdvancedDownload\XF\Pub\Controller;

use XF\Mvc\Entity\Entity;
use XF\Mvc\ParameterBag;

class Attachment extends XFCP_Attachment
{
    
    public function actionIndex(ParameterBag $params)
    {
        /** Get attachment */
        $attachment = $this->em()->find('XF:Attachment', $params->attachment_id);
        if (!$attachment)
		{
			throw $this->exception($this->notFound());
		}

		if ($attachment->temp_hash)
		{
			$hash = $this->filter('hash', 'str');
			if ($attachment->temp_hash !== $hash)
			{
				return $this->noPermission();
			}
		}
		else
		{
			if (!$attachment->canView($error))
			{
				return $this->noPermission($error);
			}
		}

		if (!$this->filter('no_canonical', 'bool'))
		{
			$this->assertCanonicalUrl($this->buildLink('attachments', $attachment));
		}

        /** Get option values */
        $options = \XF::options();
        $fileExtensions = $options->DC_AdvancedDownload_fileEx;
        $fileExSplited = preg_split('/\s+/', $fileExtensions, -1, PREG_SPLIT_NO_EMPTY);

        if ( in_array($attachment->extension, $fileExSplited) ) {
            return $this->plugin('XF:Attachment')->displayAttachment($attachment);
        }
        
        /** Build attachment and post link */
        $baseUrl = (isset($_SERVER['HTTPS']) ? "https" : "http") . "://$_SERVER[HTTP_HOST]";                       
        $attachmentUrl = $baseUrl . \XF::app()->router()->buildLink('attachments', $attachment);
        $postUrl = $baseUrl . '/posts/' . $attachment->Container->post_id;
        
        /** Build hashes */
        $section1 = 1;  if(isset($_GET['sess'])) $section1 = $_GET['sess'];
        $section2 = 2;  if(isset($_POST['sess'])) $section2 = $_POST['sess'];

        $fileSize = $attachment->file_size;
        if ( $fileSize >= 1000000 ) {
            $fileSize = round($attachment->file_size * 0.000001, 2);
            $fileSizeEx = ' MB';
        } elseif ( $fileSize >=1000 && $fileSize < 1000000 ) {
            $fileSize = round($attachment->file_size * 0.001, 2);
            $fileSizeEx = ' KB';
        } elseif ( $fileSize < 1000 ) {
            $fileSizeEx = ' Bytes';
        }
        
        /** Return action index */
		
        if ( $section1 != $section2 and (\XF::visitor()->canViewAdvancedDownload($error)) ) {
			$viewParams = [
                'sess' => md5('DC_AdvancedDownload_DownloadInternal'.\XF::$time),
                'fileUrl' => $attachmentUrl,
                'fileName' => $attachment->filename,
                'fileSize' => "$fileSize $fileSizeEx",
                'fileEx' => $attachment->extension,
                'postUrl' => $postUrl,
                'viewCount' => $attachment->view_count
            ];
			return $this->view('AdvancedDownload:DownloadPage', 'DC_AdvancedDownload_DownloadInternal', $viewParams);
		} else {
			return $this->plugin('XF:Attachment')->displayAttachment($attachment);
		}
    }
}