<?php

namespace DC\AdvancedDownload\XF\Pub\Controller;

use XF\Mvc\ParameterBag;
use XF\Pub\Controller\AbstractController;

class ResourceVersion extends XFCP_ResourceVersion
{
    public function actionDownload(ParameterBag $params)
    {	
		$visitor = \XF::visitor();

		if (!$visitor->canViewAdvancedDownload($error))
		{
			throw $this->exception($this->noPermission($error));
		}
        $version = $this->assertViewableVersion($params->resource_version_id);
		if (!$version->isDownloadable())
		{
			return $this->redirect($this->buildLink('resources', $version->Resource));
		}

		if (!$version->canDownload($error))
		{
			return $this->noPermission($error);
		}

		$resource = $version->Resource;

		/** @var \XF\Entity\Attachment|null $attachment */
		$attachment = null;

		if (!$version->download_url)
		{
			$attachments = $version->getRelationFinder('Attachments')->fetch();

			$file = $this->filter('file', 'uint');
			if ($attachments->count() == 0)
			{
				return $this->error(\XF::phrase('attachment_cannot_be_shown_at_this_time'));
			}
			else if ($attachments->count() == 1)
			{
				$attachment = $attachments->first();
			}
			else if ($file && isset($attachments[$file]))
			{
				$attachment = $attachments[$file];
			}

			if (!$attachment)
			{
				$viewParams = [
					'resource' => $resource,
					'version' => $version,
					'files' => $attachments
				];
				return $this->view('XFRM:ResourceVersion\DownloadChooser', 'xfrm_resource_download_chooser', $viewParams);

			}
		}

		$visitor = \XF::visitor();

		if ($visitor->user_id != $resource->user_id)
		{
			$this->repository('XFRM:ResourceWatch')->autoWatchResource($version->Resource, \XF::visitor());
		}

		$this->repository('XFRM:ResourceVersion')->logDownload($version);

		if ($version->download_url)
		{
			$viewParams = [
                'fileUrl' => $version->download_url
            ];
			return $this->view('AdvancedDownload:DownloadPage', 'DC_AdvancedDownload_DownloadExternal', $viewParams);
		} else {
            /** Get option values */
            $options = \XF::options();
            $fileExtensions = $options->DC_AdvancedDownload_fileEx;
            $fileExSplited = preg_split('/\s+/', $fileExtensions, -1, PREG_SPLIT_NO_EMPTY);

            if ( in_array($attachment->extension, $fileExSplited) ) {
                return $this->plugin('XF:Attachment')->displayAttachment($attachment);
            }
            
            /** Build attachment and post link */
			$baseUrl = (isset($_SERVER['HTTPS']) ? "https" : "http") . "://$_SERVER[HTTP_HOST]";                       
			$attachmentUrl = $baseUrl . \XF::app()->router()->buildLink('resources', $version);
			$postUrl = $baseUrl . '/resources/' . $attachment->Container->resource_id;
            
            /** Build hashes */
            $section1 = 1;  if(isset($_GET['sess'])) $section1 = $_GET['sess'];
			$section2 = 2;  if(isset($_POST['sess'])) $section2 = $_POST['sess'];

			$fileSize = $attachment->file_size;
			if ( $fileSize >= 1000000 ) {
				$fileSize = round($attachment->file_size * 0.000001, 2);
				$fileSizeEx = ' MB';
			} elseif ( $fileSize >=1000 && $fileSize < 1000000 ) {
				$fileSize = round($attachment->file_size * 0.001, 2);
				$fileSizeEx = ' KB';
			} elseif ( $fileSize < 1000 ) {
				$fileSizeEx = ' Bytes';
			}
            
            /** Return action index */
            if ( $section1 != $section2 ) {
                $viewParams = [
                    'sess' => md5('DC_AdvancedDownload_DownloadInternal'.\XF::$time),
					'fileUrl' => $attachmentUrl,
					'fileName' => $attachment->filename,
					'fileSize' => "$fileSize $fileSizeEx",
					'fileEx' => $attachment->extension,
					'postUrl' => $postUrl,
					'viewCount' => $attachment->view_count
                ];
                return $this->view('AdvancedDownload:DownloadPage', 'DC_AdvancedDownload_DownloadInternal', $viewParams);
            } else {
                return $this->plugin('XF:Attachment')->displayAttachment($attachment);
            }
        }
    }
}